@@ -2,11 +2,11 @@
 echo x11/xxkb | pkg_src_fetch_var -f 'PKGNAME PKGPATH MAINTAINER' |
 normalize_version |
 cmp 'pkg_src_fetch_var #1' \
-'+	xxkb-1.11	x11/xxkb	vle@gmx.net
+'+	xxkb-1.11	x11/xxkb	cheusov@NetBSD.org
 '
 
 echo x11/xxkb | pkg_src_fetch_var -v'PKGNAME PKGPATH MAINTAINER' |
 normalize_version |
 cmp 'pkg_src_fetch_var #2' \
-'+	xxkb-1.11	x11/xxkb	vle@gmx.net
+'+	xxkb-1.11	x11/xxkb	cheusov@NetBSD.org
 '
